
[![Build and Test , Package PyPI](https://github.com/arita37/adatasets/actions/workflows/build%20and%20release.yml/badge.svg)](https://github.com/arita37/adatasets/actions/workflows/build%20and%20release.yml)


[Pypi       https://pypi.org/project/adatasets/#history](https://pypi.org/project/adatasets/#history)



### adatasets
      Dataset for ML testing
            
      ```
      from adatasets import test_dataset_classification_fake 
      df, pars = test_dataset_classification_fake(nrows=500)
    
      coly   = pars['coly']
      colnum = pars['colnum']
      colcat = pars['colcat']      
      ``` 




### Install
    pip install adatasets
    
    

    Stable : pip install -e git+https://github.com/arita37/myutil.git@0.0.1#egg=myutil

    Latest : pip install -e git+https://github.com/arita37/myutil.git#egg=myutil
    
    
    
